@@ -1,4 +1,4 @@
-import os, datetime, sys
+import os, datetime
 from glob import glob
 import pandas as pd
 
@@ -539,9 +539,7 @@ def correctPredictionsSingleDate(folder, dStr):
     oriDF = pd.DataFrame(data=None)
 
     prevFolder = os.path.join(folder, prevStr)
-    # for feature_file in sorted(glob(os.path.join(prevFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
-    for feature_file in sorted(glob(os.path.join(prevFolder, '*features.csv'))):
-
+    for feature_file in sorted(glob(os.path.join(prevFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
@@ -549,18 +547,14 @@ def correctPredictionsSingleDate(folder, dStr):
 
 
     thisFolder = os.path.join(folder, dStr)
-    # for feature_file in sorted(glob(os.path.join(thisFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
-    for feature_file in sorted(glob(os.path.join(thisFolder, '*features.csv'))):
-
+    for feature_file in sorted(glob(os.path.join(thisFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
         oriDF = pd.concat([oriDF, odf], ignore_index=True)
 
     nextFolder = os.path.join(folder, nextStr)
-    # for feature_file in sorted(glob(os.path.join(nextFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
-    for feature_file in sorted(glob(os.path.join(nextFolder, '*features.csv'))):
-
+    for feature_file in sorted(glob(os.path.join(nextFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.feature.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
